@@ -7,13 +7,13 @@
 # (c) 2011-11-06 Bernd Schlapsi <brot@gmx.info>
 # Released under the same license terms as gPodder itself.
 
+import logging
 import os
 import subprocess
 
 import gpodder
 from gpodder import util
 
-import logging
 logger = logging.getLogger(__name__)
 
 _ = gpodder.gettext
@@ -21,7 +21,7 @@ _ = gpodder.gettext
 __title__ = _('Normalize audio with re-encoding')
 __description__ = _('Normalize the volume of audio files with normalize-audio')
 __authors__ = 'Bernd Schlapsi <brot@gmx.info>'
-__doc__ = 'http://wiki.gpodder.org/wiki/Extensions/NormalizeAudio'
+__doc__ = 'https://gpodder.github.io/docs/extensions/normalizeaudio.html'
 __payment__ = 'https://flattr.com/submit/auto?user_id=BerndSch&url=http://wiki.gpodder.org/wiki/Extensions/NormalizeAudio'
 __category__ = 'post-download'
 
@@ -91,13 +91,14 @@ class gPodderExtension:
 
         cmd = [CONVERT_COMMANDS.get(extension, 'normalize-audio'), filename]
 
+        # Set cwd to prevent normalize from placing files in the directory gpodder was started from.
         if gpodder.ui.win32:
-            p = util.Popen(cmd)
+            p = util.Popen(cmd, cwd=episode.channel.save_dir)
             p.wait()
             stdout, stderr = ("<unavailable>",) * 2
         else:
-            p = util.Popen(cmd, stdout=subprocess.PIPE,
-                    stderr=subprocess.PIPE)
+            p = util.Popen(cmd, cwd=episode.channel.save_dir,
+                    stdout=subprocess.PIPE, stderr=subprocess.PIPE)
             stdout, stderr = p.communicate()
 
         if p.returncode == 0:
@@ -105,7 +106,7 @@ class gPodderExtension:
             gpodder.user_extensions.on_notification_show(_('File normalized'),
                     episode.title)
         else:
-            logger.warn('normalize-audio failed: %s / %s', stdout, stderr)
+            logger.warning('normalize-audio failed: %s / %s', stdout, stderr)
 
     def convert_episodes(self, episodes):
         for episode in episodes:
