@@ -3,16 +3,20 @@
 # (c) 2014-04-10 Alex Mayer <magictrick4906@aim.com>
 # Released under the same license terms as gPodder itself.
 
+# Use a logger for debug output - this will be managed by gPodder
+import logging
 import os
 import shutil
 
-# Use a logger for debug output - this will be managed by gPodder
-import logging
+import gpodder
+
 logger = logging.getLogger(__name__)
+_ = gpodder.gettext
+
 
 # Provide some metadata that will be displayed in the gPodder GUI
-__title__ = 'Rockbox Cover Art Sync'
-__description__ = 'Copy Cover Art To Rockboxed Media Player'
+__title__ = _('Rockbox Cover Art Sync')
+__description__ = _('Copy Cover Art To Rockboxed Media Player')
 __only_for__ = 'gtk, cli'
 __authors__ = 'Alex Mayer <magictrick4906@aim.com>'
 
@@ -35,7 +39,7 @@ class gPodderExtension:
             device_folder = device.get_episode_folder_on_device(episode)
             episode_art = os.path.join(episode_folder, "folder.jpg")
             device_art = os.path.join(device_folder, self.config.art_name_on_device)
-            # make sure we have art to copy and it doesnt already exist
+            # make sure we have art to copy and it doesn't already exist
             if os.path.isfile(episode_art) and not os.path.isfile(device_art):
                 logger.info('Syncing cover art for %s', episode.channel.title)
                 # copy and rename art
