@@ -16,6 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
+import datetime
 import html
 import logging
 from urllib.parse import urlparse
@@ -201,7 +202,8 @@ class gPodderShownotesText(gPodderShownotes):
         heading = episode.title
         subheading = _('from %s') % (episode.channel.title)
         details = self.details_fmt % {
-            'date': util.format_date(episode.published),
+            'date': '{} {}'.format(datetime.datetime.fromtimestamp(episode.published).strftime('%H:%M'),
+                util.format_date(episode.published)),
             'size': util.format_filesize(episode.file_size, digits=1)
             if episode.file_size > 0 else "-",
             'duration': episode.get_play_info_string()}
@@ -342,7 +344,8 @@ class gPodderShownotesHTML(gPodderShownotes):
         heading = '<h3>%s</h3>' % html.escape(episode.title)
         subheading = _('from %s') % html.escape(episode.channel.title)
         details = '<small>%s</small>' % html.escape(self.details_fmt % {
-            'date': util.format_date(episode.published),
+            'date': '{} {}'.format(datetime.datetime.fromtimestamp(episode.published).strftime('%H:%M'),
+                util.format_date(episode.published)),
             'size': util.format_filesize(episode.file_size, digits=1)
             if episode.file_size > 0 else "-",
             'duration': episode.get_play_info_string()})
