@@ -161,7 +161,7 @@ class JsonConfig(object):
                     work_queue.append((data[key], value))
                 elif type(value) != type(data[key]):  # noqa
                     # Type mismatch of current value and default
-                    if type(value) == int and type(data[key]) == float:
+                    if isinstance(value, int) and isinstance(data[key], float):
                         # Convert float to int if default value is int
                         data[key] = int(data[key])
 
