@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
@@ -21,7 +20,6 @@
 # Soundcloud.com API client module for gPodder
 # Thomas Perl <thp@gpodder.org>; 2009-11-03
 
-import email
 import json
 import logging
 import os
@@ -147,7 +145,7 @@ class SoundcloudUser(object):
             total_count = len(json_tracks)
 
             if len(tracks) == 0 and total_count > 0:
-                logger.warn("Download of all %i %s of user %s is disabled" %
+                logger.warning("Download of all %i %s of user %s is disabled" %
                             (total_count, feed, self.username))
             else:
                 logger.info("%i/%i downloadable tracks for user %s %s feed" %
@@ -167,7 +165,8 @@ class SoundcloudUser(object):
                 yield {
                     'title': track.get('title', track.get('permalink')) or _('Unknown track'),
                     'link': track.get('permalink_url') or 'https://soundcloud.com/' + self.username,
-                    'description': track.get('description') or _('No description available'),
+                    'description': util.remove_html_tags(track.get('description') or ''),
+                    'description_html': '',
                     'url': url,
                     'file_size': int(filesize),
                     'mime_type': filetype,
