@@ -434,15 +434,15 @@ def get_channel_id_url(url, feed_data=None):
     if 'youtube.com' in url:
         try:
             if feed_data is None:
-                r = util.urlopen(url)
+                r = util.urlopen(url, cookies={'SOCS': 'CAI'})
                 if not r.ok:
                     raise YouTubeError('Youtube "%s": %d %s' % (url, r.status_code, r.reason))
             else:
                 r = feed_data
             # video page may contain corrupt HTML/XML, search for tag to avoid exception
-            m = re.search(r'channel_id=([^"]+)">', r.text)
+            m = re.search(r'(channel_id=([^"]+)">|"channelId":"([^"]+)")', r.text)
             if m:
-                channel_id = m.group(1)
+                channel_id = m.group(2) or m.group(3)
             else:
                 raw_xml_data = io.BytesIO(r.content)
                 xml_data = xml.etree.ElementTree.parse(raw_xml_data)
@@ -632,10 +632,11 @@ def parse_youtube_url(url):
             return new_url
 
         # look for channel URL in page
+        logger.debug("Unknown Youtube URL, trying to extract channel ID...")
         new_url = get_channel_id_url(url)
         if new_url:
             logger.debug("New Youtube URL: {}".format(new_url))
-            return new_url
+            return parse_youtube_url(new_url)
 
     logger.debug("Not a valid Youtube URL: {}".format(url))
     return url
